@@ -26,6 +26,15 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "../config.h"
 
+#include <string.h>
+#include <sys/socket.h>
+#include <sys/un.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <glib/gstdio.h>
+
 #include "xpad-app.h"
 #include "help.h"
 #include "xpad-pad.h"
@@ -34,16 +43,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "xpad-session-manager.h"
 #include "xpad-tray.h"
 
-#include <string.h>
-#include <sys/socket.h>
-#include <sys/un.h>
-#include <stdio.h>
-#include <stdlib.h>
-
-#include <glib.h>
-#include <glib/gi18n.h>
-#include <glib/gstdio.h>
-
 /* Seems that some systems (sun-sparc-solaris2.8 at least), need the following three #defines.
    These were provided by Alan Mizrahi <alan@cesma.usb.ve>.
 */
@@ -91,6 +90,8 @@ static gboolean		xpad_app_quit_if_no_pads    (XpadPadGroup *group);
 static gboolean		xpad_app_first_idle_check   (XpadPadGroup *group);
 static gboolean		xpad_app_pass_args          (void);
 static gboolean		xpad_app_open_proc_file     (void);
+static void enable_unix_signal_handlers();
+static void unix_signal_handler(int sig) __attribute__(( __noreturn__ ));
 
 static void
 xpad_app_init (int argc, char **argv)
@@ -203,12 +204,31 @@ xpad_app_init (int argc, char **argv)
 gint main (gint argc, gchar **argv)
 {
 	xpad_app_init (argc, argv);
-
+	enable_unix_signal_handlers();
 	gtk_main ();
 
 	return 0;
 }
 
+static void enable_unix_signal_handlers() {
+	signal(SIGINT, unix_signal_handler);
+	signal(SIGQUIT, unix_signal_handler);
+	signal(SIGTERM, unix_signal_handler);
+}
+
+static void unix_signal_handler(int sig)
+{
+	switch (sig) {
+		case SIGINT:
+		case SIGTERM:
+		case SIGQUIT:
+			xpad_app_quit();
+			break;
+	}
+
+	exit(EXIT_FAILURE);
+}
+
 /* parent and secondary may be NULL.
  * Returns when user dismisses error.
  */
@@ -273,6 +293,8 @@ xpad_app_quit (void)
 
 	/* Free the memory used by the settings menu. */
 	g_clear_object (&settings);
+
+	exit(EXIT_SUCCESS);
 }
 
 static gboolean
@@ -497,7 +519,7 @@ xpad_app_load_pads (void)
 			if ((show || option_show) && !option_hide)
 				gtk_widget_show (pad);
 			else if (show) /* pad thought it would show, we should save that it didn't */
-				xpad_pad_save_info (XPAD_PAD (pad));
+				xpad_pad_save_info_delayed (XPAD_PAD (pad));
 			opened ++;
 		}
 	}
@@ -720,6 +742,7 @@ xpad_app_pass_args (void)
 	int client_fd;
 	struct sockaddr_un master;
 	fd_set fdset;
+	fd_set exception;
 	gchar buf [129];
 	gchar *args = NULL;
 	guint size;
@@ -753,9 +776,11 @@ xpad_app_pass_args (void)
 	{
 		/* wait for response */
 		FD_ZERO (&fdset);
+		FD_ZERO (&exception);
 		FD_SET (client_fd, &fdset);
+		FD_SET (client_fd, &exception);
 		/* block until we are answered, or an error occurs */
-		select (client_fd + 1, &fdset, NULL, &fdset, NULL);
+		select (client_fd + 1, &fdset, NULL, &exception, NULL);
 
 		do
 		{
