@@ -25,9 +25,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "../config.h"
 
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gtksourceview/gtksource.h>
+
 #include "xpad-pad.h"
-#include "fio.h"
-#include "help.h"
 #include "xpad-app.h"
 #include "xpad-pad-properties.h"
 #include "xpad-periodic.h"
@@ -36,9 +38,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "xpad-text-view.h"
 #include "xpad-toolbar.h"
 #include "xpad-tray.h"
-
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
+#include "fio.h"
+#include "help.h"
 
 struct XpadPadPrivate
 {
@@ -137,6 +138,7 @@ static void xpad_pad_open_properties (XpadPad *pad);
 static void xpad_pad_open_preferences (XpadPad *pad);
 static void xpad_pad_close_all (XpadPad *pad);
 static void xpad_pad_sync_title (XpadPad *pad);
+static void xpad_pad_stick_unstick (XpadPad *pad);
 static gboolean xpad_pad_leave_notify_event (GtkWidget *pad, GdkEventCrossing *event);
 static gboolean xpad_pad_enter_notify_event (GtkWidget *pad, GdkEventCrossing *event);
 
@@ -358,11 +360,6 @@ static void xpad_pad_constructed (GObject *object)
 
 	pad->priv->clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
 
-	if (pad->priv->sticky)
-		gtk_window_stick (pad_window);
-	else
-		gtk_window_unstick (pad_window);
-
 	xpad_pad_sync_title (pad);
 
 	/* Add CSS style class, so the styling can be overridden by a GTK theme */
@@ -486,16 +483,34 @@ xpad_pad_show (XpadPad *pad)
 	if (pad->priv->location_valid)
 		gtk_window_move (GTK_WINDOW (pad), pad->priv->x, pad->priv->y);
 
+	xpad_pad_stick_unstick (pad);
+
+	/* Show the pad and set the cursor into the pad */
+	gtk_window_present (GTK_WINDOW (pad));
+	gtk_widget_grab_focus (GTK_WIDGET (pad->priv->textview));
+
+	/* Save the new visibility status to the disk */
+	xpad_pad_save_info_delayed (pad);
+}
+
+void
+xpad_pad_set_sticky (XpadPad *pad, gboolean is_sticky)
+{
+	pad->priv->sticky = is_sticky;
+	xpad_pad_stick_unstick (pad);
+	xpad_pad_save_info_delayed (pad);
+}
+
+static void
+xpad_pad_stick_unstick (XpadPad *pad)
+{
 	if (pad->priv->sticky)
 		gtk_window_stick (GTK_WINDOW (pad));
 	else
 		gtk_window_unstick (GTK_WINDOW (pad));
-
-	/* Show the pad and set the cursor into the pad */
-        gtk_window_present (GTK_WINDOW (pad));
-        gtk_widget_grab_focus (GTK_WIDGET (pad->priv->textview));
 }
 
+
 static gboolean toolbar_timeout (XpadPad *pad)
 {
 	if (!pad || !pad->priv || !pad->priv->toolbar_timeout)
@@ -824,7 +839,7 @@ xpad_pad_close (XpadPad *pad)
 	if (pad->priv->properties)
 		gtk_widget_destroy (pad->priv->properties);
 
-	xpad_pad_save_info (pad);
+	xpad_pad_save_info_delayed (pad);
 
 	g_signal_emit (pad, signals[CLOSED], 0);
 }
@@ -1061,11 +1076,11 @@ xpad_pad_toolbar_size_allocate (XpadPad *pad, GtkAllocation *event)
 	/* safe cast from gint to guint */
 	if (event->height >= 0) {
 		pad->priv->toolbar_height = (guint) event->height;
-	}
-	else {
+	} else {
 		g_warning("There is a problem in the program Xpad. In function 'xpad_pad_toolbar_size_allocate' the variable 'event->height' is not a positive number. Please send a bugreport to https://bugs.launchpad.net/xpad/+filebug to help improve Xpad.");
 		pad->priv->toolbar_height = 0;
 	}
+
 	return FALSE;
 }
 
@@ -1080,22 +1095,24 @@ xpad_pad_configure_event (XpadPad *pad, GdkEventConfigure *event)
 
 	/* safe cast from gint to guint */
 	if (eWidth >= 0 && eHeight >=0 ) {
+		/* If the width or height has changed, save it. */
 		if (pad->priv->width != (guint) eWidth || pad->priv->height != (guint) eHeight) {
 			pad->priv->toolbar_pad_resized = TRUE;
 			pad->priv->width = (guint) eWidth;
 			pad->priv->height = (guint) eHeight;
-			pad->priv->unsaved_info = TRUE;
+			xpad_pad_save_info_delayed(pad);
 		}
 	}
 	else {
 		g_warning("There is a problem in the program Xpad. In function 'xpad_pad_configure_event' the variable 'event->width' or 'event->height' is not a positive number. Please send a bugreport to https://bugs.launchpad.net/xpad/+filebug to help improve Xpad.");
 	}
 
+	/* If the location of the pad has changed, save it. */
 	if (pad->priv->x != event->x || pad->priv->y != event->y) {
 		pad->priv->x = event->x;
 		pad->priv->y = event->y;
 		pad->priv->location_valid = TRUE;
-		pad->priv->unsaved_info = TRUE;
+		xpad_pad_save_info_delayed(pad);
 	}
 
 	/*
@@ -1326,10 +1343,7 @@ xpad_pad_load_info (XpadPad *pad, gboolean *show)
 		xpad_text_view_set_colors (pad->priv->textview, &text_color, &back_color);
 	}
 
-	if (pad->priv->sticky)
-		gtk_window_stick (GTK_WINDOW (pad));
-	else
-		gtk_window_unstick (GTK_WINDOW (pad));
+	xpad_pad_stick_unstick (pad);
 
 	if (show)
 		*show = !hidden;
@@ -1359,6 +1373,7 @@ xpad_pad_save_info (XpadPad *pad)
 			return;
 		gtk_window_set_role (GTK_WINDOW (pad), pad->priv->infoname);
 	}
+
 	/* create content file if it doesn't exist yet */
 	if (!pad->priv->contentname)
 	{
@@ -1815,6 +1830,7 @@ void xpad_pad_save_info_delayed (XpadPad *pad)
 	xpad_periodic_save_info_delayed (pad);
 }
 
+/* Save pad without delay, for example on application shutdown. */
 void xpad_pad_save_unsaved (XpadPad *pad)
 {
 	if (pad->priv->unsaved_content)
